import os
import platform
import requests
import time
import zipfile

def download_and_extract_zip(zip_url, extract_to):
    # Ensure the folder exists, if not create it
    if not os.path.exists(extract_to):
        os.makedirs(extract_to)

    # Download the zip file
    response = requests.get(zip_url, stream=True)
    total_size = int(response.headers.get('content-length', 0))
    block_size = 8192  # 8K
    zip_file_path = os.path.join(extract_to, "temp_download.zip")

    with open(zip_file_path, 'wb') as file:
        for data in response.iter_content(block_size):
            file.write(data)
            downloaded_size = file.tell()
            progress_percentage = (downloaded_size / total_size) * 100
            print(f"Downloaded: {downloaded_size} of {total_size} bytes ({progress_percentage:.2f}%)", end='\r')
    print()  # Newline for cleaner output after progress is done

    # Extract the contents of the zip file
    with zipfile.ZipFile(zip_file_path, 'r') as zip_ref:
        zip_ref.extractall(extract_to)

    # Remove the downloaded zip file
    os.remove(zip_file_path)

url = "https://huggingface.co/MonsterMMORPG/SECourses/resolve/main/cudnn-windows-x86_64-8.9.4.25_cuda11.zip"
folder = os.path.join(os.getcwd(), "stable-diffusion-webui", "venv", "Lib", "site-packages", "nvidia", "cudnn", "bin")
download_and_extract_zip(url, folder)
print ("8.9.4.25 cudnn files downloaded and installed")
